using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Text;
using System.Windows.Forms;
using SemitransparentImaging;


namespace DemoApplication
{
    public partial class StForm_Features : SemitransparentForm.StForm
    {
        public StForm_Features()
        {
            InitializeComponent();

            //Note: Assigning CornerRadius to Button with set its CornerRadius Permanently,
            //it will not vary according to Forms CornerRadius,
            //can check it by adjusting CornerRadius Trackbar.(Given this option to specify value for Buttons Indepently)
            this.CloseButton.CornerRadius = 4;

            CtlOpacity.Text = "Opacity";
            CtlCornerRadius.Text = "Corner Radius";
            CtlControlBoxHeight.Text = "ControlBoxHeight";

            CtlOpacity.trackBar.Maximum = 100;
            CtlOpacity.numericUpDown.Maximum = 100;
            CtlCornerRadius.trackBar.Maximum = 20;
            CtlCornerRadius.numericUpDown.Maximum = 20;
            CtlControlBoxHeight.trackBar.Maximum = 50;
            CtlControlBoxHeight.numericUpDown.Maximum = 50;

            CtlOpacity.Value = Convert.ToInt32(this.Opacity * 100);
            CtlCornerRadius.Value = this.CornerRadius;
            CtlControlBoxHeight.Value = this.ControlBoxHeight;

            CtlOpacity.ValueChanged += new EventHandler(opacityTrackBar_ValueChanged);
            CtlCornerRadius.ValueChanged += new EventHandler(cornerRadiusTrackBar_ValueChanged);
            CtlControlBoxHeight.ValueChanged += new EventHandler(boxHeight_ValueChanged);

            this.Load += new EventHandler(StForm_Features_Load);
        }

        void StForm_Features_Load(object sender, EventArgs e)
        {
            //for Colors.
            cpBgColor.Color = Color.FromArgb(45, 45, 45);
            cpBgColor.ColorChanged += new EventHandler(brush_Changed);

            cpBackgroundColor.Color = this.BackgroundColor;
            cpBackgroundColor.ColorChanged += new EventHandler(backgroundColor_Changed);

            cpActiveColor.Color = this.ActiveFormColor;
            cpActiveColor.ColorChanged += new EventHandler(activeColor_Changed);

            cpInactiveColor.Color = this.InactiveFormColor;
            cpInactiveColor.ColorChanged += new EventHandler(inactiveColor_Changed);

            cpCtrlBoxColor.Color = Color.DarkSlateGray;
            cpCtrlBoxColor.ColorChanged += new EventHandler(borderBrush_Changed);


            //for HatchStyles.
            cbBgHatchPattern.SelectedIndexChanged += new EventHandler(brush_Changed);
            Array hatchStyles = Enum.GetValues(typeof(HatchStyle));
            for (int i = 0; i < hatchStyles.Length; i++)
            {
                cbBgHatchPattern.Items.Add(hatchStyles.GetValue(i));
                cbCtrlBHatchPattern.Items.Add(hatchStyles.GetValue(i));
            }
            cbBgHatchPattern.SelectedItem = HatchStyle.Weave;//.Percent25;
            cbCtrlBHatchPattern.SelectedItem = HatchStyle.Percent25;
            cbCtrlBHatchPattern.SelectedIndexChanged += new EventHandler(borderBrush_Changed);

            //for GradientStyles
            cbCtrlBGradientType.SelectedIndexChanged += new System.EventHandler(this.borderBrush_Changed);
            Array gradientStyles = Enum.GetValues(typeof(LinearGradientMode));
            for (int i = 0; i < gradientStyles.Length; i++)
            {
                cbBgGradientType.Items.Add(gradientStyles.GetValue(i));
                cbCtrlBGradientType.Items.Add(gradientStyles.GetValue(i));
            }
            cbBgGradientType.SelectedItem = LinearGradientMode.BackwardDiagonal;
            cbCtrlBGradientType.SelectedItem = LinearGradientMode.Horizontal;
            this.cbBgGradientType.SelectedIndexChanged += new System.EventHandler(this.brush_Changed);
        }

        void brush_Changed(object sender, EventArgs e)
        {
            if (rbBgGradient.Checked)
            {
                SetBackGroundBrush(cpBgColor.Color, (LinearGradientMode)cbBgGradientType.SelectedItem);
            }
            else
            {
                SetBackGroundBrush((HatchStyle)cbBgHatchPattern.SelectedItem, cpBgColor.Color);//Color.FromArgb(45, 45, 45));
            }
            this.Refresh();
        }

        void borderBrush_Changed(object sender, EventArgs e)
        {
            if (rbCtrlBGradient.Checked)
            {
                SetControlBoxBrush(cpCtrlBoxColor.Color, (LinearGradientMode)cbCtrlBGradientType.SelectedItem);
            }
            else
            {
                SetControlBoxBrush((HatchStyle)cbCtrlBHatchPattern.SelectedItem, cpCtrlBoxColor.Color);
            }
            this.Refresh();
        }

        void backgroundColor_Changed(object sender, EventArgs e)
        {
            this.BackgroundColor = cpBackgroundColor.Color;
            this.Refresh();
        }

        void activeColor_Changed(object sender, EventArgs e)
        {
            this.ActiveFormColor = cpActiveColor.Color;
            this.Refresh();
        }

        void inactiveColor_Changed(object sender, EventArgs e)
        {
            this.InactiveFormColor = cpInactiveColor.Color;
            this.Refresh();
        }


        void opacityTrackBar_ValueChanged(object sender, EventArgs e)
        {
            this.Opacity = CtlOpacity.trackBar.Value / 100.0;
        }

        void cornerRadiusTrackBar_ValueChanged(object sender, EventArgs e)
        {
            this.CornerRadius = CtlCornerRadius.trackBar.Value;
        }

        void boxHeight_ValueChanged(object sender, EventArgs e)
        {
            this.ControlBoxHeight = CtlControlBoxHeight.trackBar.Value;
        }

        private void rbBg_CheckedChanged(object sender, EventArgs e)
        {
            if (rbBgGradient.Checked)
            {
                lbBgGradientType.Visible = true;
                cbBgGradientType.Visible = true;

                lbBgHatchPattern.Visible = false;
                cbBgHatchPattern.Visible = false;
            }
            else
            {
                lbBgGradientType.Visible = false;
                cbBgGradientType.Visible = false;

                lbBgHatchPattern.Visible = true;
                cbBgHatchPattern.Visible = true;
            }

            brush_Changed(sender, e);
        }

        private void rbCtrlBHatchStyle_CheckedChanged(object sender, EventArgs e)
        {
            if (rbCtrlBGradient.Checked)
            {
                lbCtrlBGradientType.Visible = true;
                cbCtrlBGradientType.Visible = true;

                lbCtrlBHatchPattern.Visible = false;
                cbCtrlBHatchPattern.Visible = false;
            }
            else
            {
                lbCtrlBGradientType.Visible = false;
                cbCtrlBGradientType.Visible = false;

                lbCtrlBHatchPattern.Visible = true;
                cbCtrlBHatchPattern.Visible = true;
            }
            borderBrush_Changed(sender, e);
        }
    }
}